@@ -20,7 +20,7 @@ func init() {
 ## POSITIONAL ARGUMENTS
 
 <shell>
-: The shell program. Either bash or zsh.
+: The shell program. Supports bash, zsh, and fish.
 
 ## EXAMPLES
 
@@ -28,6 +28,11 @@ Add bash completion for the current user.
 '''
 $ step completion bash >> ~/.bash_completion
 '''
+
+Add fish completions for the current user.
+'''
+$ step completion fish | source
+'''
 `,
 		Flags: []cli.Flag{
 			flags.HiddenNoContext,
